Documentation
¶
Index ¶
- Constants
- Variables
- func ShowJSON(res gjson.Result, opts ShowJSONOpts) error
- func ShowJSONIterator[T any](iter jsonview.Iterator[T], itemsToDisplay int64, opts ShowJSONOpts) error
- func ValidateBaseURL(value, source string) error
- type BodyContentType
- type FileEmbedStyle
- type FilePathValue
- type ShowJSONOpts
Constants ¶
const Version = "1.1.2" // x-release-please-version
Variables ¶
var ( Command *cli.Command CommandErrorBuffer bytes.Buffer )
var OutputFormats = []string{"auto", "explore", "json", "jsonl", "pretty", "raw", "yaml"}
Functions ¶
func ShowJSON ¶
func ShowJSON(res gjson.Result, opts ShowJSONOpts) error
ShowJSON displays a single JSON result to the user.
func ShowJSONIterator ¶
func ShowJSONIterator[T any](iter jsonview.Iterator[T], itemsToDisplay int64, opts ShowJSONOpts) error
ShowJSONIterator displays an iterator of values to the user. Use itemsToDisplay = -1 for no limit.
func ValidateBaseURL ¶
ValidateBaseURL checks that a base URL is correctly prefixed with a protocol scheme and produces a better error message than the person would see otherwise if it doesn't.
Types ¶
type BodyContentType ¶
type BodyContentType int
const ( EmptyBody BodyContentType = iota MultipartFormEncoded ApplicationJSON ApplicationOctetStream )
type FileEmbedStyle ¶
type FileEmbedStyle int
const ( // EmbedText reads referenced files fully into memory and substitutes the file's contents back into the // value as a string. Binary files are base64-encoded. Used for JSON request bodies and for headers and // query parameters, where the file contents need to be serialized inline. EmbedText FileEmbedStyle = iota // EmbedIOReader replaces file references with an io.Reader that streams the file's contents. Used for // `multipart/form-data` and `application/octet-stream` request bodies, where files are uploaded as binary // parts rather than embedded into a text value. EmbedIOReader )
type FilePathValue ¶
type FilePathValue string
FilePathValue is a string wrapper that marks a value as a file path whose contents should be read and embedded in the request. Unlike a regular string, embedFilesValue always treats a FilePathValue as a file path without needing the "@" prefix.
type ShowJSONOpts ¶
type ShowJSONOpts struct {
ExplicitFormat bool // true if the user explicitly passed --format
Format string // output format (auto, explore, json, jsonl, pretty, raw, yaml)
RawOutput bool // like jq -r: print strings without JSON quotes
Stderr io.Writer // stderr for warnings; injectable for testing; defaults to os.Stderr
Stdout *os.File // stdout (or pager); injectable for testing; defaults to os.Stdout
Title string // display title
Transform string // GJSON path to extract before displaying
}
ShowJSONOpts configures how JSON output is displayed.
Source Files
¶
- adminorganizationadminapikey.go
- adminorganizationauditlog.go
- adminorganizationcertificate.go
- adminorganizationgroup.go
- adminorganizationgrouprole.go
- adminorganizationgroupuser.go
- adminorganizationinvite.go
- adminorganizationproject.go
- adminorganizationprojectapikey.go
- adminorganizationprojectcertificate.go
- adminorganizationprojectgroup.go
- adminorganizationprojectgrouprole.go
- adminorganizationprojectratelimit.go
- adminorganizationprojectrole.go
- adminorganizationprojectserviceaccount.go
- adminorganizationprojectuser.go
- adminorganizationprojectuserrole.go
- adminorganizationrole.go
- adminorganizationusage.go
- adminorganizationuser.go
- adminorganizationuserrole.go
- audiospeech.go
- audiotranscription.go
- audiotranslation.go
- batch.go
- betaassistant.go
- betachatkitsession.go
- betachatkitthread.go
- betathread.go
- betathreadmessage.go
- betathreadrun.go
- betathreadrunstep.go
- call.go
- chatcompletion.go
- chatcompletionmessage.go
- clientsecret.go
- cmd.go
- cmdutil.go
- cmdutil_unix.go
- completion.go
- container.go
- containerfile.go
- containerfilecontent.go
- conversation.go
- embedding.go
- file.go
- finetuningalphagrader.go
- finetuningcheckpointpermission.go
- finetuningjob.go
- finetuningjobcheckpoint.go
- flagoptions.go
- image.go
- inputitem.go
- inputtoken.go
- item.go
- model.go
- moderation.go
- response.go
- skill.go
- skillcontent.go
- skillversion.go
- skillversioncontent.go
- suggest.go
- upload.go
- uploadpart.go
- vectorstore.go
- vectorstorefile.go
- vectorstorefilebatch.go
- version.go
- video.go
Click to show internal directories.
Click to hide internal directories.